#
# spec file for package libqt5-qtlottie
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
Name:           libqt5-qtlottie
Version:        5.15.15+kde0
Release:        1.1
Summary:        Qt 5 Quick Lottie Addon
License:        GPL-3.0-or-later
Group:          Development/Libraries/X11
URL:            https://www.qt.io
%define base_name libqt5
%define real_version 5.15.15
%define so_version 5.15.15
%define tar_version qtlottie-everywhere-src-%{version}
Source:         %{tar_version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  libQt5Gui-private-headers-devel >= %{real_version}
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Qml) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{real_version}
%requires_ge    libQt5Gui5

%description
This package provides a QML module for Qt 5 which allows playing of BodyMovin
files from QML.

%package -n libQt5Bodymovin5
Summary:        Qt 5 BodyMovin Library
Group:          System/Libraries

%description -n libQt5Bodymovin5
Qt is a set of libraries for developing applications.

This package includes a library for reading BodyMovin animation files.

%package -n libQt5Bodymovin-devel
Summary:        Qt Development Kit
Group:          Development/Libraries/X11
Requires:       libQt5Bodymovin5 = %{version}

%description -n libQt5Bodymovin-devel
You need this package if you want to compile programs with the Qt BodyMovin
library.

%package -n libQt5Bodymovin-private-headers-devel
Summary:        Headers for the unstable API of the Qt5 BodyMovin library
Group:          Development/Libraries/X11
Requires:       libQt5Bodymovin-devel = %{version}

%description -n libQt5Bodymovin-private-headers-devel
You need this package if you want to compile programs against the unstable API
of the Qt5 BodyMovin library.

%prep
%autosetup -n %{tar_version}

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
find %{buildroot}/%{_libqt5_libdir} -type f -name '*la' -print -exec perl -pi -e 's,-L%{_builddir}/\S+,,g' {} +
find %{buildroot}/%{_libqt5_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} + -exec sed -i -e "s,^moc_location=.*,moc_location=%{_lib}qt5_bindir/moc," -e "s,uic_location=.*,uic_location=%{_lib}qt5_bindir/uic," {} +
find %{buildroot}/%{_libqt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} +

# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%post -n libQt5Bodymovin5 -p /sbin/ldconfig
%postun -n libQt5Bodymovin5 -p /sbin/ldconfig

%files -n libQt5Bodymovin5
%license LICENSE.*
%{_libqt5_libdir}/libQt5Bodymovin.so.*

%files
%license LICENSE.*
%dir %{_libqt5_archdatadir}/qml/Qt/
%dir %{_libqt5_archdatadir}/qml/Qt/labs/
%dir %{_libqt5_archdatadir}/qml/Qt/labs/lottieqt/
%{_libqt5_archdatadir}/qml/Qt/labs/lottieqt/liblottieqtplugin.so
%{_libqt5_archdatadir}/qml/Qt/labs/lottieqt/plugins.qmltypes
%{_libqt5_archdatadir}/qml/Qt/labs/lottieqt/qmldir

# The entire library is private for now, so not all files are present.
%files -n libQt5Bodymovin-devel
%license LICENSE.*
%exclude %{_libqt5_includedir}/QtBodymovin/%{so_version}
%{_libqt5_includedir}/QtBodymovin
%{_libqt5_libdir}/cmake/Qt5Bodymovin
%{_libqt5_libdir}/libQt5Bodymovin.prl
%{_libqt5_libdir}/libQt5Bodymovin.so
#%%{_libqt5_libdir}/pkgconfig/Qt5Bodymovin.pc
#%%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_bodymovin.pri

%files -n libQt5Bodymovin-private-headers-devel
%license LICENSE.*
%{_libqt5_includedir}/QtBodymovin/%{so_version}/
%{_libqt5_archdatadir}/mkspecs/modules/qt_lib_bodymovin_private.pri

%changelog
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde0, rebased upstream:
  * Bump version to 5.15.15
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde0, rebased upstream:
  * Bump version to 5.15.14
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde0, rebased upstream:
  * Bump version to 5.15.13
* Tue Feb 13 2024 Christophe Marin <christophe@krop.fr>
- Fix subpackage %%files
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde0, rebased upstream:
  * Bump version to 5.15.12
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde0, rebased upstream:
  * No code changes
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde0, rebased upstream:
  * No code changes
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde2, rebased upstream:
  * No code changes
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde0, rebased upstream:
  * Fix assert when cloning hidden BMGFill
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde0, rebased upstream:
  * No code changes
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde0, rebased upstream:
  * No code changes
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde0, rebased upstream:
  * Revert "Update commercial license headers"
  * Update commercial license headers
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde1:
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlottie.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlottie.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtlottie.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtlottie.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtlottie.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtlottie.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtlottie.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Mon Jul  8 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Initial packaging (boo#1140586)
